
<!--

#################################################
### THIS FILE WAS AUTOGENERATED! DO NOT EDIT! ###
#################################################
# file to edit: index.ipynb
# command to build the docs after a change: nbdev_build_docs

-->

# Project name here

> Summary description here.


This file will become your README and also the index of your documentation.

## Install

`pip install your_project_name`

## How to use

Fill me in please! Don't forget code examples:
<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```
1+1
```

</div>
<div class="output_area" markdown="1">




    2



</div>

</div>
